Crate kcr_keycloak_org

Crate kcr_keycloak_org 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the keycloak.org group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

keycloak.org/v1alpha1

  • KeycloakBackup
  • KeycloakClient
  • KeycloakRealm
  • Keycloak
  • KeycloakUser

Modules

v1alpha1